@@ -18,7 +18,7 @@ use Readonly 1.03;
 our (@EXPORT_OK, %EXPORT_TAGS);
 
 BEGIN {
-	our $VERSION = '0.22';
+	our $VERSION = '0.23';
 
 	XSLoader::load('File::Map', $VERSION);
 }
@@ -92,7 +92,7 @@ File::Map - Memory mapping made simple and safe.
 
 =head1 VERSION
 
-Version 0.20
+Version 0.23
 
 =head1 SYNOPSIS
 
@@ -312,7 +312,7 @@ An attempt was made to C<sync>, C<remap>, C<unmap>, C<pin>, C<unpin>, C<advise>
 
 =item * Could not %f: %e
 
-Your OS didn't allow File::Map to do what you asked it to do for the reason specified in %e
+Your OS didn't allow File::Map to do what you asked it to do for the reason specified in %e.
 
 =item * Trying to %f on an unlocked map
 
@@ -322,6 +322,10 @@ You tried to C<wait_until>, C<notify> or C<broadcast> on an unlocked variable.
 
 A zero length anonymous map is not possible (or in any way useful).
 
+=item * Can't remap a shared mapping
+
+An attempts was made to remap a mapping that is shared among different threads, this is not possible.
+
 =back
 
 =head2 Warnings
